/*
  ==============================================================================

    This file contains the basic framework code for a JUCE plugin editor.

  ==============================================================================
*/

#include "PluginProcessor.h"
#include "PluginEditor.h"

//==============================================================================
VanillaTestAudioProcessorEditor::VanillaTestAudioProcessorEditor (VanillaTestAudioProcessor& p)
    : AudioProcessorEditor (&p), audioProcessor (p)
{
    // Make sure that before the constructor has finished, you've set the
    // editor's size to whatever you need it to be.
    setSize (400, 300);
    
    juce::LookAndFeel::setDefaultLookAndFeel (audioProcessor.mainLookAndFeel.get());
    //setLookAndFeel (audioProcessor.mainLookAndFeel.get());
    
    //myMenu.setLookAndFeel (audioProcessor.mainLookAndFeel.get());
    myMenu.addItem (1, "Item 1", true, false);
    myMenu.addItem (2, "Item 2", true, true);
    myMenu.addSeparator();
    myMenu.addItem (3, "Item 3", true, false);
    myMenu.addItem (4, "Item 4", true, false);
    
    addAndMakeVisible (&myLabel);
    myLabel.setText ("This should be big! Click me!", juce::dontSendNotification);
    myLabel.setInterceptsMouseClicks (false, false);
}

VanillaTestAudioProcessorEditor::~VanillaTestAudioProcessorEditor()
{
    juce::LookAndFeel::setDefaultLookAndFeel (nullptr);
    //setLookAndFeel (nullptr);
    myMenu.setLookAndFeel (nullptr);
}

void VanillaTestAudioProcessorEditor::mouseDown (const juce::MouseEvent& e)
{
    myMenu.showMenuAsync (juce::PopupMenu::Options().withTargetComponent (&myLabel));
}

//==============================================================================
void VanillaTestAudioProcessorEditor::paint (juce::Graphics& g)
{
    // (Our component is opaque, so we must completely fill the background with a solid colour)
    g.fillAll (juce::Colours::darkgrey);

    g.setColour (juce::Colours::white);

    g.setFont (14.0f);
    g.drawFittedText ("Font, regular, 14.0f", juce::Rectangle<int>(5, 5, 200, 25), juce::Justification::left, 1);
    
    g.setFont (juce::Font (15.0f, juce::Font::bold));
    g.drawFittedText ("Font, bold, 15.0f", juce::Rectangle<int>(5, 30, 200, 25), juce::Justification::left, 1);
    
    g.setFont (16.0f);
    g.drawFittedText ("Font, regular, 16.0f", juce::Rectangle<int>(5, 55, 200, 25), juce::Justification::left, 1);
    
    g.setFont (juce::Font (17.0f, juce::Font::bold));
    g.drawFittedText ("Font, bold, 17.0f", juce::Rectangle<int>(5, 80, 95, 25), juce::Justification::left, 1);
}

void VanillaTestAudioProcessorEditor::resized()
{
    // This is generally where you'll want to lay out the positions of any
    // subcomponents in your editor..
    
    myLabel.setBounds (getBounds());
}
